Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Locate ¶
Locate returns a path to the Chrome binary, or an empty string if Chrome installation is not found.
func PromptDownload ¶
func PromptDownload()
PromptDownload asks user if he wants to download and install Chrome, and opens a download web page if the user agrees.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.